fn get_recorded_state_diffs<CTX: ContextTr<Db: DatabaseExt>>(
ccx: &mut CheatsCtxt<'_, CTX>,
) -> BTreeMap<Address, AccountStateDiffs>Expand description
Helper function to returns state diffs recorded for each changed account.
fn get_recorded_state_diffs<CTX: ContextTr<Db: DatabaseExt>>(
ccx: &mut CheatsCtxt<'_, CTX>,
) -> BTreeMap<Address, AccountStateDiffs>Helper function to returns state diffs recorded for each changed account.