track_snapshot_restore

Function track_snapshot_restore 

fn track_snapshot_restore<FEN: FoundryEvmNetwork>(
    ccx: &mut CheatsCtxt<'_, '_, FEN>,
    journaled_state: JournaledState,
    restored: &JournaledState,
)
Records the live journal replaced by a snapshot restoration so that a failing enclosing frame can reinstate it and unwind its journaled writes.